@@ -4,6 +4,7 @@ from .PropertyDefinition import PropertyDefinition
 from .WorkItem import WorkItemActivity 
 from .Activity import Activity, Input
 from .Deviation import Deviation
+from .Media import Media
 
 
 __all__ = [
@@ -15,5 +16,6 @@ __all__ = [
     'Activity',
     'WorkItem',
     'Input',
-    'WorkItemActivity'
+    'WorkItemActivity',
+    'Media'
 ]
\ No newline at end of file
